@@ -42,30 +42,21 @@
 #include "nautilus-search-bar.h"
 #include <eel/eel-debug.h>
 #include <eel/eel-marshal.h>
-#include <eel/eel-gdk-extensions.h>
-#include <eel/eel-gdk-pixbuf-extensions.h>
-#include <eel/eel-gtk-extensions.h>
 #include <eel/eel-gtk-macros.h>
-#include <eel/eel-stock-dialogs.h>
 #include <eel/eel-string.h>
-#include <eel/eel-vfs-extensions.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <gdk/gdkx.h>
 #include <gdk/gdkkeysyms.h>
 #include <gtk/gtkmain.h>
 #include <gtk/gtkmenubar.h>
 #include <gtk/gtkmenuitem.h>
-#include <gtk/gtkoptionmenu.h>
 #include <gtk/gtktogglebutton.h>
 #include <gtk/gtkvbox.h>
 #include <glib/gi18n.h>
-#include <libgnome/gnome-macros.h>
-#include <libgnome/gnome-util.h>
-#include <libgnomeui/gnome-messagebox.h>
-#include <libgnomeui/gnome-uidefs.h>
-#include <libgnomeui/gnome-window-icon.h>
+#ifdef HAVE_X11_XF86KEYSYM_H
+#include <X11/XF86keysym.h>
+#endif
 #include <libgnomevfs/gnome-vfs-uri.h>
-#include <libgnomevfs/gnome-vfs-utils.h>
 #include <libnautilus-private/nautilus-file-utilities.h>
 #include <libnautilus-private/nautilus-file-attributes.h>
 #include <libnautilus-private/nautilus-global-preferences.h>
@@ -132,6 +123,27 @@ G_DEFINE_TYPE_WITH_CODE (NautilusWindow, nautilus_window, GTK_TYPE_WINDOW,
 			 G_IMPLEMENT_INTERFACE (NAUTILUS_TYPE_WINDOW_INFO,
 						nautilus_window_info_iface_init));
 
+static const struct {
+	unsigned int keyval;
+	const char *action;
+} extra_window_keybindings [] = {
+#ifdef HAVE_X11_XF86KEYSYM_H
+	{ XF86XK_AddFavorite,	NAUTILUS_ACTION_ADD_BOOKMARK },
+	{ XF86XK_Favorites,	NAUTILUS_ACTION_EDIT_BOOKMARKS },
+	{ XF86XK_Go,		NAUTILUS_ACTION_GO_TO_LOCATION },
+/* TODO?{ XF86XK_History,	NAUTILUS_ACTION_HISTORY }, */
+	{ XF86XK_HomePage,      NAUTILUS_ACTION_GO_HOME },
+	{ XF86XK_OpenURL,	NAUTILUS_ACTION_GO_TO_LOCATION },
+	{ XF86XK_Refresh,	NAUTILUS_ACTION_RELOAD },
+	{ XF86XK_Reload,	NAUTILUS_ACTION_RELOAD },
+	{ XF86XK_Search,	NAUTILUS_ACTION_SEARCH },
+	{ XF86XK_Start,		NAUTILUS_ACTION_GO_HOME },
+	{ XF86XK_Stop,		NAUTILUS_ACTION_STOP },
+	{ XF86XK_ZoomIn,	NAUTILUS_ACTION_ZOOM_IN },
+	{ XF86XK_ZoomOut,	NAUTILUS_ACTION_ZOOM_OUT }
+#endif
+};
+
 static void
 icons_changed_callback (GObject *factory, NautilusWindow *window)
 {
@@ -259,8 +271,6 @@ nautilus_window_go_up_signal (NautilusWindow *window, gboolean close_behind)
 	return TRUE;
 }
 
-
-
 void
 nautilus_window_go_up (NautilusWindow *window, gboolean close_behind)
 {
@@ -366,7 +376,6 @@ nautilus_window_allow_reload (NautilusWindow *window, gboolean allow)
 	action = gtk_action_group_get_action (window->details->main_action_group,
 					      NAUTILUS_ACTION_RELOAD);
 	gtk_action_set_sensitive (action, allow);
-
 }
 
 void
@@ -376,10 +385,8 @@ nautilus_window_go_home (NautilusWindow *window)
 
 	g_return_if_fail (NAUTILUS_IS_WINDOW (window));
 
-	home_uri = gnome_vfs_get_uri_from_local_path (g_get_home_dir ());
-	
-	g_assert (home_uri != NULL);
-	nautilus_window_go_to (window, home_uri);
+	home_uri = nautilus_get_home_directory_uri ();
+	nautilus_window_open_location (window, home_uri, FALSE);
 	g_free (home_uri);
 }
 
@@ -742,6 +749,41 @@ nautilus_window_realize (GtkWidget *widget)
 	update_cursor (NAUTILUS_WINDOW (widget));
 }
 
+static gboolean
+nautilus_window_key_press_event (GtkWidget *widget,
+				 GdkEventKey *event)
+{
+	NautilusWindow *window;
+	int i;
+
+	window = NAUTILUS_WINDOW (widget);
+
+	for (i = 0; i < G_N_ELEMENTS (extra_window_keybindings); i++) {
+		if (extra_window_keybindings[i].keyval == event->keyval) {
+			const GList *action_groups;
+			GtkAction *action;
+
+			action = NULL;
+
+			action_groups = gtk_ui_manager_get_action_groups (window->details->ui_manager);
+			while (action_groups != NULL && action == NULL) {
+				action = gtk_action_group_get_action (action_groups->data, extra_window_keybindings[i].action);
+				action_groups = action_groups->next;
+			}
+
+			g_assert (action != NULL);
+			if (gtk_action_is_sensitive (action)) {
+				gtk_action_activate (action);
+				return TRUE;
+			}
+
+			break;
+		}
+	}
+
+	return GTK_WIDGET_CLASS (nautilus_window_parent_class)->key_press_event (widget, event);
+}
+
 /*
  * Main API
  */
@@ -1583,6 +1625,7 @@ nautilus_window_class_init (NautilusWindowClass *class)
 	GTK_WIDGET_CLASS (class)->show = nautilus_window_show;
 	GTK_WIDGET_CLASS (class)->size_request = nautilus_window_size_request;
 	GTK_WIDGET_CLASS (class)->realize = nautilus_window_realize;
+	GTK_WIDGET_CLASS (class)->key_press_event = nautilus_window_key_press_event;
 	class->add_current_location_to_history_list = real_add_current_location_to_history_list;
 	class->get_title = real_get_title;
 	class->set_title = real_set_title;
